Create and save log-logistic golden fixture
Source:R/golden_fixtures.R
dot-hzr_create_loglogistic_golden_fixture.RdGenerates a synthetic dataset and fits a log-logistic model, storing results as a golden fixture for validation.
R/golden_fixtures.R
dot-hzr_create_loglogistic_golden_fixture.RdGenerates a synthetic dataset and fits a log-logistic model, storing results as a golden fixture for validation.